==> structure-server-0.0.5.tgz: package/index.js <==
/**
 * Module Dependencies
 *
 * @ignore
 */
var bodyParser = require('body-parser')
var contentLength = require('express-content-length-validator')
var cors = require('cors')
var Dispatcher = require('structure-dispatcher').default
var express = require('express')
var helmet = require('helmet')
var hpp = require('hpp')
var logger = require('structure-logger')
var path = require('path')
var Router = require('structure-router')
var serveStatic = require('serve-static')
var WebsocketServer = require('structure-websocket-server')

function removePoweredBy(req, res, next) {
  res.removeHeader('X-Powered-By')
  next()
}

/**
 * Server Class
 *
 * @public
 * @class Server
 */
class Server {

  /**
   * Server constructor
   *
   * @public
   * @constructor
   * @param {Object} options - Options
   */
  constructor(options = {}) {

    var defaults = {
      cursors: options.cursors || [],
      db: true,
      drain: true,
      sockets: true
    }

    this.options = Object.assign({}, defaults, options)

    this.server = express()

    /*
    TODO: Add whitelist
    */
    this.server.use(cors())

    /*if(process.env.NODE_ENV != 'test') {
      this.server.use(require('express-status-monitor')())
    }*/
    this.server.use(serveStatic(path.join(__dirname, '../public')))
    this.server.use(bodyParser.urlencoded({extended: true}))
    this.server.use(bodyParser.json({strict: false}))
    //this.server.use(removePoweredBy)
    this.server.use(helmet())
    this.server.use(hpp())
    this.server.use(contentLength.validateMax({max: process.env.MAX_CONTENT_LENGTH, status: 400, message: 'stop it!'}))

    if(process.env.NODE_ENV != 'test') {
      this.server.use(this.logRequestInfo)
    }

    this.router = options.router || new Router({
      dispatcher: options.dispatcher || new Dispatcher(),
      routes: options.routes
    })

    this.router.start(this.server)

    let routes = []

    for(let i = 0, l = this.router.routesList.length; i < l; i++) {
      const item = this.router.routesList[i]
      let path = (item.routeName) ? `/${item.routeName}${item.route.path}` : item.route.path
      path = path.replace(/\/$/, '')

      const key = Object.keys(item.methods).map(function(k) {
        return k.toUpperCase()
      })[0]

      const row = {}
      row[key] = path

      routes.push(row)
    }

    // For debuggin
    this.routesList = routes

    this.server.get(`/api/${process.env.API_VERSION}`, function routesListHandler(req, res) {

      res.json({
        routes
      })

    })

  }

  closeCursors() {
    var cursors = require('./cursors')

    for(let i = 0, l = cursors.length; i < l; i++) {
      var cursor = cursors[i]
      cursor.close()
    }

    cursors = []

  }

  /**
   * Log each HTTP request's method and url
   *
   * @private
   * @param {Object} req - Express req
   * @param {Object} res - Express res
   * @param {Function} next - Express next
   */
  logRequestInfo(req, res, next) {

    logger.info(req.method, req.originalUrl)
    next()

  }

  /**
   * Start the HTTP Server
   *
   * @public
   */
  start() {

    this.server = this.server.listen(this.options.port || process.env.EXPRESS_PORT)

    if(this.options.sockets) {
      this.wss = new WebsocketServer(this.server)
    }

    if(this.options.db) {
      this.cursors = []
    }

    logger.debug('Structure API started at:', `http://localhost:${process.env.EXPRESS_PORT}`)

  }

  /**
   * Stop the HTTP Server
   *
   * @public
   */
  stop() {

    if(this.options.db) {
      var r = require('../lib/database/driver')
      if(this.options.drain) r.getPoolMaster().drain()
      this.closeCursors()
    }

    if(this.options.sockets) {
      this.wss.stop()
    }

    this.server.close()

  }

  /**
   * Add Express middleware to the Express server object
   *
   * @public
   */
  use() {

    this.server.use.apply(this.server, arguments)

  }

}

module.exports = Server

==> structure-server-0.0.11.tgz: package/index.js <==
/**
 * Module Dependencies
 *
 * @ignore
 */
var bodyParser = require('body-parser')
var contentLength = require('express-content-length-validator')
var cors = require('cors')
var express = require('express')
var helmet = require('helmet')
var hpp = require('hpp')
var logger = require('structure-logger')
var md5 = require('md5')
var path = require('path')
var Router = require('structure-router')
var serveStatic = require('serve-static')
var WebsocketServer = require('structure-websocket-server')

function removePoweredBy(req, res, next) {
  res.removeHeader('X-Powered-By')
  next()
}

/**
 * Server Class
 *
 * @public
 * @class Server
 */
class Server {

  /**
   * Server constructor
   *
   * @public
   * @constructor
   * @param {Object} options - Options
   */
  constructor(options = {}) {

    var defaults = {
      cursors: options.cursors || [],
      db: true,
      drain: true,
      sockets: true
    }

    this.options = Object.assign({}, defaults, options)
    this.pkgJson = options.pkgJson || ''
    this.server = express()

    /*
    TODO: Add whitelist
    */
    this.server.use(cors())

    /*if(process.env.NODE_ENV != 'test') {
      this.server.use(require('express-status-monitor')())
    }*/
    this.server.use(serveStatic(path.join(__dirname, '../public')))
    this.server.use(bodyParser.urlencoded({extended: true}))
    this.server.use(bodyParser.json({strict: false}))
    //this.server.use(removePoweredBy)
    this.server.use(helmet())
    this.server.use(hpp())
    //this.server.use(contentLength.validateMax({max: process.env.MAX_CONTENT_LENGTH, status: 400, message: 'stop it!'}))

    if(process.env.NODE_ENV != 'test') {
      this.server.use(this.logRequestInfo)
    }

    this.router = options.router || new Router({
      routes: options.routes
    })

    this.router.start(this.server)

    let routes = this.router.routesList

    // For debuggin
    this.routesList = routes

    this.server.get(`/api/${process.env.API_VERSION}`, function routesListHandler(req, res) {

      res.json({
        routes
      })

    })

  }

  closeCursors() {
    var cursors = require('./cursors')

    for(let i = 0, l = cursors.length; i < l; i++) {
      var cursor = cursors[i]
      cursor.close()
    }

    cursors = []

  }

  /**
   * Log each HTTP request's method and url
   *
   * @private
   * @param {Object} req - Express req
   * @param {Object} res - Express res
   * @param {Function} next - Express next
   */
  logRequestInfo(req, res, next) {

    logger.info(req.method, req.originalUrl)
    next()

  }

  /**
   * Start the HTTP Server
   *
   * @public
   */
  start() {

    process.env.STRUCTURE_HASH = md5(this.pkgJson + Date.now())

    this.server = this.server.listen(this.options.port || process.env.EXPRESS_PORT)

    if(this.options.sockets) {
      this.wss = new WebsocketServer(this.server)
    }

    if(this.options.db) {
      this.cursors = []
    }

    logger.debug('Structure API started at:', `http://localhost:${process.env.EXPRESS_PORT}`)

  }

  /**
   * Stop the HTTP Server
   *
   * @public
   */
  stop() {

    if(this.options.db) {
      var r = require('structure-driver').default
      if(this.options.drain) r.getPoolMaster().drain()
      this.closeCursors()
    }

    if(this.options.sockets) {
      this.wss.stop()
    }

    this.server.close()

  }

  /**
   * Add Express middleware to the Express server object
   *
   * @public
   */
  use() {

    this.server.use.apply(this.server, arguments)

  }

}

module.exports = Server
